@@ -88,7 +88,7 @@ int main (int argc, char **argv)
     QObject::connect(iconPage, &IconThemeConfig::updateOtherSettings, configOtherToolKits, &ConfigOtherToolKits::setConfig);
 
     /*** LXQt Theme ***/
-    LXQtThemeConfig* themePage = new LXQtThemeConfig(settings, dialog);
+    LXQtThemeConfig* themePage = new LXQtThemeConfig(settings, stylePage, dialog);
     dialog->addPage(themePage, QObject::tr("LXQt Theme"), QStringList() << QStringLiteral("preferences-desktop-color") << QStringLiteral("preferences-desktop"));
     QObject::connect(dialog, &LXQt::ConfigDialog::reset, themePage, &LXQtThemeConfig::initControls);
     QObject::connect(themePage, &LXQtThemeConfig::settingsChanged, dialog, [dialog] {
@@ -138,13 +138,23 @@ int main (int argc, char **argv)
             dialog->enableButton(QDialogButtonBox::Apply, false); // disable Apply button on resetting too
     });
 
+    app.setQuitOnLastWindowClosed(false);
+    app.connect(&app, &LXQt::SingleApplication::lastWindowClosed, [=, &mConfigAppearanceSettings] () {
+        mConfigAppearanceSettings.setValue(QStringLiteral("size"), dialog->size());
+        LXQt::SingleApplication::quit();
+
+    });
+
     dialog->setAttribute(Qt::WA_DeleteOnClose);
     dialog->setWindowIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-theme")));
     dialog->resize(mConfigAppearanceSettings.value(QStringLiteral("size")).toSize().expandedTo(QSize(600, 400)));
     dialog->show();
 
     int ret = app.exec();
-    mConfigAppearanceSettings.setValue(QStringLiteral("size"), dialog->size());
+
+    delete settings;
+    delete sessionSettings;
+
     return ret;
 }
 
