@@ -36,7 +36,7 @@
     <message>
         <location filename="../localeconfig.ui" line="194"/>
         <source>Co&amp;llation and Sorting:</source>
-        <translation>Verge&amp;lijking en ragnschikking:</translation>
+        <translation>Verge&amp;lijking en rangschikking:</translation>
     </message>
     <message>
         <location filename="../localeconfig.ui" line="226"/>
@@ -64,32 +64,32 @@
         <translation>Meeteenheden:</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="126"/>
+        <location filename="../localeconfig.cpp" line="125"/>
         <source>No change</source>
-        <translation>Niets aangepast</translation>
+        <translation>Standaard</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="313"/>
+        <location filename="../localeconfig.cpp" line="312"/>
         <source>Format Settings Changed</source>
         <translation>De instellingen zijn aangepast</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="314"/>
+        <location filename="../localeconfig.cpp" line="313"/>
         <source>Do you want to save your changes? They will take effect the next time you log in.</source>
-        <translation>Wilt u uw aanpassingen opslaan? Ze zullen worden toegepast zodra u zich opnieuw aanmeldt.</translation>
+        <translation>Wilt u uw aanpassingen opslaan? Ze zullen worden toegepast nadat u zich opnieuw heeft aangemeld.</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="417"/>
+        <location filename="../localeconfig.cpp" line="416"/>
         <source>Imperial UK</source>
         <translation>Imperiaal (VK)</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="421"/>
+        <location filename="../localeconfig.cpp" line="420"/>
         <source>Imperial US</source>
         <translation>Imperiaal (VS)</translation>
     </message>
     <message>
-        <location filename="../localeconfig.cpp" line="425"/>
+        <location filename="../localeconfig.cpp" line="424"/>
         <source>Metric</source>
         <translation>Metrisch</translation>
     </message>
@@ -97,12 +97,12 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="50"/>
+        <location filename="../main.cpp" line="49"/>
         <source>LXQt Locale Configuration</source>
-        <translation>LXQt-regio-instellingen</translation>
+        <translation>LXQt-taalinstellingen</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="55"/>
+        <location filename="../main.cpp" line="54"/>
         <source>Locale Settings</source>
         <translation>Regionale instellingen</translation>
     </message>
