@@ -31,10 +31,27 @@
 </context>
 <context>
     <name>LoadSettings</name>
+    <message>
+        <location filename="../loadsettings.cpp" line="97"/>
+        <source>Default monitor settings applied.</source>
+        <translation>De standaard beeldscherminstellingen zijn toegepast.</translation>
+    </message>
     <message>
         <location filename="../loadsettings.cpp" line="98"/>
-        <source>Default monitor settings have been applied. Use lxqt-config-monitor for adjusting your monitor settings.</source>
-        <translation>De standaard beeldscherminstellingen zijn toegepast. Als u deze wilt aanpassen, kunt u lxqt-config-monitor gebruiken.</translation>
+        <source>Adjust your screens with LXQt Monitor Settings.</source>
+        <translation>Pas uw beeldscherminstellingen aan.</translation>
+    </message>
+    <message>
+        <location filename="../loadsettings.cpp" line="107"/>
+        <source>lxqt-config-monitor: Settings applied.</source>
+        <translation>lxqt-config-monitor: de instellingen zijn toegepast.</translation>
+    </message>
+    <message>
+        <location filename="../loadsettings.cpp" line="109"/>
+        <source>lxqt-config-monitor: Settings not applied.
+If this is a Wayland compositor, you could try kanshi to configure your monitor(s).</source>
+        <translation>lxqt-config-monitor: de instellingen zijn niet toegepast.
+Als u gebruikmaakt van Wayland, probeer dan uw beeldscherm(en) in te stellen met behulp van kanshi.</translation>
     </message>
 </context>
 <context>
@@ -50,62 +67,71 @@
         <translation>Opgeslagen instellingen</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.ui" line="38"/>
+        <location filename="../managesavedsettings.ui" line="45"/>
         <source>Rename</source>
         <translation>Naam wijzigen</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.ui" line="45"/>
+        <location filename="../managesavedsettings.ui" line="52"/>
         <source>Delete</source>
         <translation>Verwijderen</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.ui" line="52"/>
-        <source>Apply</source>
-        <translation>Toepassen</translation>
-    </message>
-    <message>
-        <location filename="../managesavedsettings.cpp" line="62"/>
+        <location filename="../managesavedsettings.cpp" line="66"/>
         <source>None</source>
         <translation>Geen</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.cpp" line="65"/>
+        <location filename="../managesavedsettings.cpp" line="69"/>
         <source>Left</source>
         <translation>Links</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.cpp" line="68"/>
+        <location filename="../managesavedsettings.cpp" line="72"/>
         <source>Inverted</source>
         <translation>Omgedraaid</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.cpp" line="71"/>
+        <location filename="../managesavedsettings.cpp" line="75"/>
         <source>Right</source>
         <translation>Rechts</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.cpp" line="75"/>
-        <location filename="../managesavedsettings.cpp" line="76"/>
+        <location filename="../managesavedsettings.cpp" line="79"/>
+        <location filename="../managesavedsettings.cpp" line="80"/>
         <source>True</source>
         <translation>Waar</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.cpp" line="75"/>
-        <location filename="../managesavedsettings.cpp" line="76"/>
+        <location filename="../managesavedsettings.cpp" line="79"/>
+        <location filename="../managesavedsettings.cpp" line="80"/>
         <source>False</source>
         <translation>Onwaar</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.cpp" line="136"/>
+        <location filename="../managesavedsettings.cpp" line="139"/>
         <source>Name</source>
         <translation>Naam</translation>
     </message>
     <message>
-        <location filename="../managesavedsettings.cpp" line="136"/>
+        <location filename="../managesavedsettings.cpp" line="139"/>
         <source>Name:</source>
         <translation>Naam:</translation>
     </message>
+    <message>
+        <location filename="../managesavedsettings.cpp" line="172"/>
+        <source>Settings Activation Failed</source>
+        <translation>Toepassen van instellingen mislukt</translation>
+    </message>
+    <message>
+        <location filename="../managesavedsettings.cpp" line="173"/>
+        <source>Selected settings cannot be applied with currently active monitors.
+
+Please choose from the highlighted configurations.</source>
+        <translation>De gekozen instellingen kunnen niet worden toegepast of de actieve beeldschermen.
+
+Kies andere instellingen op basis van de gemarkeerde.</translation>
+    </message>
 </context>
 <context>
     <name>MonitorPictureDialog</name>
@@ -128,17 +154,31 @@
         <translation>Instellingen</translation>
     </message>
     <message>
-        <location filename="../monitorsettingsdialog.cpp" line="106"/>
+        <location filename="../monitorsettingsdialog.cpp" line="62"/>
+        <source>Platform Unsupported</source>
+        <translation>Niet-ondersteund systeem</translation>
+    </message>
+    <message>
+        <location filename="../monitorsettingsdialog.cpp" line="63"/>
+        <source>LXQt monitor settings are currently unsupported under this wayland compositor.
+
+You can configure your monitor(s) with kanshi.</source>
+        <translation>De LXQt-beeldscherminstellingen worden momenteel niet ondersteund in combinatie met deze Wayland-vensterbeheerder.
+
+Stel de beeldschermen in met behulp van kanshi.</translation>
+    </message>
+    <message>
+        <location filename="../monitorsettingsdialog.cpp" line="118"/>
         <source>Fast Menu</source>
         <translation>Snelmenu</translation>
     </message>
     <message>
-        <location filename="../monitorsettingsdialog.cpp" line="110"/>
+        <location filename="../monitorsettingsdialog.cpp" line="122"/>
         <source>Set position</source>
         <translation>Positie instellen</translation>
     </message>
     <message>
-        <location filename="../monitorsettingsdialog.cpp" line="229"/>
+        <location filename="../monitorsettingsdialog.cpp" line="241"/>
         <source>Advanced settings</source>
         <translation>Geavanceerde instellingen</translation>
     </message>
@@ -151,32 +191,32 @@
         <translation>Instellingen</translation>
     </message>
     <message>
-        <location filename="../monitorwidget.ui" line="29"/>
+        <location filename="../monitorwidget.ui" line="64"/>
         <source> (x)</source>
         <translation> (x)</translation>
     </message>
     <message>
-        <location filename="../monitorwidget.ui" line="45"/>
+        <location filename="../monitorwidget.ui" line="80"/>
         <source> (y)</source>
         <translation> (y)</translation>
     </message>
     <message>
-        <location filename="../monitorwidget.ui" line="78"/>
+        <location filename="../monitorwidget.ui" line="36"/>
         <source>Resolution:</source>
         <translation>Resolutie:</translation>
     </message>
     <message>
-        <location filename="../monitorwidget.ui" line="90"/>
+        <location filename="../monitorwidget.ui" line="27"/>
         <source>Enable this display</source>
         <translation>Scherm inschakelen</translation>
     </message>
     <message>
-        <location filename="../monitorwidget.ui" line="98"/>
+        <location filename="../monitorwidget.ui" line="49"/>
         <source>This is my primary display</source>
         <translation>Dit is mijn primaire scherm</translation>
     </message>
     <message>
-        <location filename="../monitorwidget.ui" line="103"/>
+        <location filename="../monitorwidget.ui" line="54"/>
         <source>This screen extends another display</source>
         <translation>Dit scherm verlengt een ander scherm</translation>
     </message>
@@ -186,12 +226,12 @@
         <translation>Geavanceerd</translation>
     </message>
     <message>
-        <location filename="../monitorwidget.ui" line="146"/>
+        <location filename="../monitorwidget.ui" line="143"/>
         <source>Refresh rate:</source>
         <translation>Ververssnelheid:</translation>
     </message>
     <message>
-        <location filename="../monitorwidget.ui" line="153"/>
+        <location filename="../monitorwidget.ui" line="133"/>
         <source>Rotation:</source>
         <translation>Draaien:</translation>
     </message>
@@ -268,7 +308,7 @@
         <translation>Omdraaien</translation>
     </message>
     <message>
-        <location filename="../monitorwidget.cpp" line="245"/>
+        <location filename="../monitorwidget.cpp" line="247"/>
         <source>%1 Hz</source>
         <translation>%1 Hz</translation>
     </message>
